@@ -12,16 +12,21 @@ import importlib.resources as pkgresources
 
 
 def prinfPath():
-    print(os.path.dirname(os.path.realpath(__file__)) + "\haarcascades\haarcascade_frontalface_default.xml")
+    print(os.path.dirname(os.path.realpath(__file__)))
 
-def prinfABC():
-    print("ABC")
+def prinfPathDirname():
+    print(os.path.dirname(__file__))
+
+def prinfPathRealpath():
+    print(os.path.realpath(__file__))
 
 def prinfLsd():
-    print("lsd" + "abc")
+    print(pkgresources.path(blurredface_sts_test, "haarcascade_frontalface_default.xml"))
+
+def prinf_is_resource():
+    print(pkgresources.is_resource(blurredface_sts_test, "haarcascade_frontalface_default.xml"))
+
 
-def prinfOs():
-    print(os.path.dirname(os.path.realpath(__file__)))
 
 #打码函数
 # size为打码的方块大小
@@ -52,7 +57,7 @@ def faceRecognizer(filepath):
         # "haarcascade_frontalface_default.xml"
         # blurredface_sts_test.haarcascade.haarcascade_frontalface_default
         # parent+"\haarcascades\haarcascade_frontalface_default.xml"
-        #"haarcascade_frontalface_default.xml"
+        # "haarcascade_frontalface_default.xml"
         pkgresources.path(blurredface_sts_test, "haarcascade_frontalface_default.xml")
 
     )
@@ -61,7 +66,7 @@ def faceRecognizer(filepath):
         # "haarcascade_frontalface_alt_tree.xml"
         # blurredface_sts_test.haarcascade.haarcascade_frontalface_alt_tree
         # parent + "\haarcascades\haarcascade_frontalface_alt_tree.xml"
-        #"haarcascade_frontalface_alt_tree.xml"
+        # "haarcascade_frontalface_alt_tree.xml"
         pkgresources.path(blurredface_sts_test, "haarcascade_frontalface_alt_tree.xml")
     )
     classifier_alt2 = cv2.CascadeClassifier(
@@ -69,7 +74,7 @@ def faceRecognizer(filepath):
         # "haarcascade_frontalface_alt2.xml"
         # blurredface_sts_test.haarcascade.haarcascade_frontalface_alt2
         # parent+"\haarcascades\haarcascade_frontalface_alt2.xml"
-        #"haarcascade_frontalface_alt2.xml"
+        # "haarcascade_frontalface_alt2.xml"
         pkgresources.path(blurredface_sts_test, "haarcascade_frontalface_alt2.xml")
     )
     classifier_alt = cv2.CascadeClassifier(
@@ -77,7 +82,7 @@ def faceRecognizer(filepath):
         # "haarcascade_frontalface_alt.xml"
         # blurredface_sts_test.haarcascade.haarcascade_frontalface_alt
         # parent + "\haarcascades\haarcascade_frontalface_alt.xml"
-        #"haarcascade_frontalface_alt.xml"
+        # "haarcascade_frontalface_alt.xml"
         pkgresources.path(blurredface_sts_test, "haarcascade_frontalface_alt.xml")
     )
     classifier_ce = cv2.CascadeClassifier(
@@ -85,7 +90,7 @@ def faceRecognizer(filepath):
         # "haarcascade_profileface.xml"
         # blurredface_sts_test.haarcascade.haarcascade_profileface
         # parent+"\haarcascades\haarcascade_profileface.xml"
-        #"haarcascade_profileface.xml"
+        # "haarcascade_profileface.xml"
         pkgresources.path(blurredface_sts_test, "haarcascade_profileface.xml")
     )
     color = (0, 0, 255)  # 定义绘制颜色
